StringExtension extension
It adds some extensions method on String type
- on
Methods
-
capitalize(
) → String -
Available on String, provided by the StringExtension extension
It capitalizes the first letter on a string -
emojiChar(
) → String -
Available on String, provided by the StringExtension extension
It renders the emoji in base of the string name