DateTimeExtension extension

Add some custom methods to the DateTime object

on

Methods

getHour() String

Available on DateTime, provided by the DateTimeExtension extension

It writes the full minute for any string format
getMinute() String

Available on DateTime, provided by the DateTimeExtension extension

It writes the full minute for any string format
next(int day) DateTime

Available on DateTime, provided by the DateTimeExtension extension